@@ -175,8 +175,9 @@ class UNET(nn.Module):
             mask for class i. Note that class 0 is reserved for background.
         first_feature_num (int): An int specifying the number of features to
             be used in the first DoubleConv layer.
-        layer_num (int): Number of layers to use in the UNET architecture.
-            The ith layer contains first_feature_num * 2**i features.
+        num_layers (int): Number of layers to use in the UNET architecture.
+            The ith layer contains first_feature_num * 2**i features. Note 
+            that if img_size // 2**num_layers < 1 then the model will break.
         kernel_size (int): A kernel of shape (kernel_size, kernel_size)
             will be applied to the imgs during both Conv2d layers of
             DoubleConv.
